/***************************************************************************
**
**  This file is part of geopsyfigs.
**
**  geopsyfigs is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  geopsyfigs is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2006-03-23
**  Copyright: 2006-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#include <QtPlugin>

#include "GeopsyFigs.h"
#include "geopsyfigsVersion.h"
#include "geopsyfigsInstallPath.h"
#include "SciFigsVersion.h"

// Force DLL dependency (required under Windows)
#ifdef Q_OS_WIN
#include <GeopsyGui.h>
TimeWindow fake(DateTime::minimumTime, DateTime::maximumTime);
#endif

const char * GeopsyFigs::interfaceVersion() const
{
  return SCIFIGS_VERSION;
}

PACKAGE_INFO("geopsyfigs", GEOPSYFIGS)

#if(QT_VERSION < QT_VERSION_CHECK(5, 0, 0))
Q_EXPORT_PLUGIN2(geopsyfigs, GeopsyFigs)
#endif
